"use strict";
const Request = require("./request");
const BaseClient = require("./base-client");
class Client extends BaseClient {
    constructor(prefix, headers) {
        super();
        this._prefix = prefix;
        if (headers)
            this.set(headers);
    }
    get(path) {
        return this.build('GET', path);
    }
    head(path) {
        return this.build('HEAD', path);
    }
    post(path) {
        return this.build('POST', path);
    }
    put(path) {
        return this.build('PUT', path);
    }
    patch(path) {
        return this.build('PATCH', path);
    }
    delete(path) {
        return this.build('DELETE', path);
    }
    del(path) {
        return this.build('DELETE', path);
    }
    cert(certstr) {
        this._cert = certstr;
        return this;
    }
    key(keystr) {
        this._key = keystr;
        return this;
    }
    ca(castrs) {
        this._ca = castrs;
        return this;
    }
    build(method, path) {
        const req = new Request(method, this._prefix + (path || ''))
            .set(this._headers)
            .retry(this._retry)
            .timeout(this._ttl);
        // Pass through TLS options
        if (this._cert)
            req.cert(this._cert);
        if (this._key)
            req.key(this._key);
        if (this._ca)
            req.ca(this._ca);
        return req;
    }
}
module.exports = Client;
